@@ -1,12 +1,12 @@
-
 from __future__ import unicode_literals
 
 from django.contrib import admin
-from .models import Memcached
+from .models import Dashboard
 
 from django.conf.urls import patterns, url
 from . import views
 
+
 class MemcachedAdmin(admin.ModelAdmin):
     def has_add_permission(self, request):
         return False
@@ -21,8 +21,9 @@ class MemcachedAdmin(admin.ModelAdmin):
             url(r'^flush/$', self.admin_site.admin_view(views.flush), name='mc_flush'),
             url(r'^stats/(?P<server_name>.+)$', self.admin_site.admin_view(views.stats), name='mc_stats'),
             url(r'^slabs/(?P<server_name>.+)$', self.admin_site.admin_view(views.slabs), name='mc_slabs'),
+            url(r'^server_status/$', self.admin_site.admin_view(views.server_status), name='mc_server_status'),
         )
         return urlpatterns + urls
 
 
-admin.site.register(Memcached, MemcachedAdmin)
\ No newline at end of file
+admin.site.register(Dashboard, MemcachedAdmin)
\ No newline at end of file
